@@ -22,7 +22,7 @@
 #include "printingwizard.h"
 #include "printprogress.h"
 #include "printstyle.h"
-#include "kaddressbookgrantlee/grantleeprint.h"
+#include <KaddressbookGrantlee/GrantleePrint>
 
 #include <KContacts/Addressee>
 
@@ -31,7 +31,6 @@
 #include <QPrinter>
 #include <QTextDocument>
 #include <QFile>
-#include <QDir>
 
 using namespace KABPrinting;
 
@@ -39,7 +38,6 @@ GrantleePrintStyle::GrantleePrintStyle(const QString &themePath, PrintingWizard
     : PrintStyle(parent)
     , m_themePath(themePath)
 {
-
     QFile previewFile(QString(themePath + QStringLiteral("/preview.png")));
     if (previewFile.exists()) {
         setPreview(previewFile.fileName());
